
# Type: regulates, process to process




URI: [biolink:regulates_process_to_process](https://w3id.org/biolink/vocab/regulates_process_to_process)


## Domain and Range

[Occurrent](Occurrent.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [regulates](regulates.md)

## Children

 *  [negatively regulates, process to process](negatively_regulates_process_to_process.md)
 *  [positively regulates, process to process](positively_regulates_process_to_process.md)

## Used by

 * [ActivityAndBehavior](ActivityAndBehavior.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [MolecularActivity](MolecularActivity.md)
 * [Occurrent](Occurrent.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [Procedure](Procedure.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002211 |

